pub(crate) struct ExecutionControl<'context, S>where
S: ExecutionCommandSource,{
context: &'context mut CommandExecutionContext<S>,
frame: Frame,
}Expand description
Queue and frame operations available only to custom internal executors.
Fields
context: &'context mut CommandExecutionContext<S>frame: FrameImplementations
Sourceimpl<'context, S> ExecutionControl<'context, S>where
S: ExecutionCommandSource,
impl<'context, S> ExecutionControl<'context, S>where
S: ExecutionCommandSource,
pub(crate) const fn new( context: &'context mut CommandExecutionContext<S>, frame: Frame, ) -> Self
pub(crate) const fn current_frame(&self) -> &Frame
pub(crate) fn queue_next(&mut self, action: impl EntryAction<S>)
Sourcepub(crate) fn suspend(&mut self, suspension: impl CommandSuspension<S>)
pub(crate) fn suspend(&mut self, suspension: impl CommandSuspension<S>)
Suspends at this queue position until the supplied work produces a resume action.
pub(crate) fn queue_contexts( &mut self, chain: ContextChain<S, SteelCommandRuntime>, original_source: Arc<S>, sources: Vec<Arc<S>>, modifiers: ChainModifiers, )
pub(crate) fn discard_frame(&mut self)
pub(crate) fn queue_fallthrough(&mut self)
pub(crate) fn return_success(&mut self, result: i32)
pub(crate) fn return_failure(&mut self)