pub(crate) struct CommandExecutionContext<S>where
S: ExecutionCommandSource,{
command_limit: usize,
fork_limit: usize,
queue_limit: usize,
command_quota: usize,
queue_overflow: bool,
command_queue: VecDeque<CommandQueueEntry<S>>,
new_top_commands: Vec<CommandQueueEntry<S>>,
suspension: Option<ActiveSuspension<S>>,
current_frame_depth: usize,
}Expand description
Vanilla-style command action queue retained only while explicitly suspended.
Fields
command_limit: usizefork_limit: usizequeue_limit: usizecommand_quota: usizequeue_overflow: boolcommand_queue: VecDeque<CommandQueueEntry<S>>new_top_commands: Vec<CommandQueueEntry<S>>suspension: Option<ActiveSuspension<S>>current_frame_depth: usizeImplementations
Sourceimpl<S> CommandExecutionContext<S>where
S: ExecutionCommandSource,
impl<S> CommandExecutionContext<S>where
S: ExecutionCommandSource,
pub(crate) fn new(command_limit: usize, fork_limit: usize) -> Self
pub(crate) fn queue_initial_command( &mut self, chain: ContextChain<S, SteelCommandRuntime>, source: S, return_value_consumer: CommandResultCallback, )
pub(crate) fn run(&mut self) -> ExecutionStop
Sourcepub(crate) fn poll_suspension(&mut self) -> ExecutionStop
pub(crate) fn poll_suspension(&mut self) -> ExecutionStop
Polls the active suspension once and resumes the retained queue when it is ready.
pub(crate) fn suspension_order(&self) -> Option<CommandSuspensionOrder>
Sourcepub(crate) fn cancel(&mut self)
pub(crate) fn cancel(&mut self)
Cancels active and queued suspension work and discards the retained command queue.
pub(crate) const fn fork_limit(&self) -> usize
pub(crate) const fn increment_cost(&mut self)
const fn create_top_frame( &self, return_value_consumer: CommandResultCallback, ) -> Frame
fn queue_next(&mut self, frame: Frame, action: impl EntryAction<S>)
fn queue_boxed(&mut self, frame: Frame, action: Box<dyn EntryAction<S>>)
fn queue_entry(&mut self, entry: CommandQueueEntry<S>)
fn push_new_commands(&mut self)
fn discard(&mut self, frame: &Frame)
fn cancel_command_queue(&mut self)
fn cancel_new_top_commands(&mut self)
Sourceimpl CommandExecutionContext<CommandSource>
impl CommandExecutionContext<CommandSource>
pub(crate) fn for_source(source: &CommandSource) -> Self